
*     ***************************************************************** * 
*     ***************************************************************** * 
*       File-Name:      2017PVS.do                                      * 
*       Date:           February 21, 2017                               * 
*       Author:         Gschwend & Norpoth                              * 
*       Purpose:      	Prediction of 2017 Bundestag election           * 
* 	    Input File:                                                     * 
*       Data Output:                                                    *               
*     ****************************************************************  * 
*     ****************************************************************  * 



** You need to download the clarify-suite by typing for instance:
** net install clarify




** In the section about chancellor popularity we can easily change the current PB values
** The code defines them as global macro. Then we do only have to call the respective macro ($merkel or $schulz) again, 
** when generating predictions.

** 05/06/17: TG added newest PB values (as of June 2017)
** 27/02/17: TG added code to calculate Pr(SPD17>CDU17)
** 27/02/17: TG added code to obtain Lijung-Box Q (and correlations)
** 27/02/17: TG added code to generate figure of Chances of Winning
** 05/03/17: TG added code to implement placebo test a la Lauterdale/Linzer 2015 IJF paper
** 09/03/17: TG added code to generate SPD-Linke prediction
** 18/03/17: TG added code to generate figure with SPD>CDU simulation
** 18/04/17: TG added code to update prediction for PVS manuscript

clear
set more off
version 12

  
use "BTW1953_2013.dta", clear


* The model (+ diagnostics) for table 1
tsset timevar
cor incvt normvt chan2grand term
reg incvt normvt chan2grand term
wntestq incvt
wntestq incvt, lags(5)


list  year incvt normvt  term chan2grand, clean



*****************
** Normal Vote **
*****************


** Depending on the forecasting target we need to change the respective value for normvt in 2017
** Thus, we create different verions for the nomal vote variable

gen     normvt_c   = normvt         //for CDU/CSU
gen     normvt_cf  = normvt         //for CDU/CSU-FDP
gen     normvt_cg  = normvt         //for CDU/CSU-Green
gen     normvt_cfg = normvt         //for CDU/CSU-FDP-Green "Jamaika Coalition"

gen     normvt_s   = normvt         //for SPD
gen     normvt_sg  = normvt         //for SPD-Green
gen     normvt_r2  = normvt         //for SPD-Linke
gen     normvt_sfg = normvt         //for SPD-FDP-Green "Traffic Light Coalition"
gen     normvt_r2g = normvt         //for SPD-Green-Linke "R2G Coalition"



** Normal Vote values for 2017 depending on forecasting target

* Results of party (2013+2009+2005)/3
*
* CDU/CSU :        (41.5+33.8+35.2)/3 = 36.8
* SPD :            (25.7+23.0+34.2)/3 = 27.6
* FDP :            (4.8 +14.6+ 9.8)/3 =  9.7
* Green            (8.4 +10.7+ 8.1)/3 =  9.1
* Linke            (8.6+ 11.9+ 8.7)/3 =  9.7

* normvt_cf:  (41.5+33.8+35.2)/3 + (4.8 +14.6+ 9.8)/3 = 46.6
* normvt_cg:  (41.5+33.8+35.2)/3 + (8.4 +10.7+ 8.1)/3 = 45.9
* normvt_cfg: (41.5+33.8+35.2)/3 + (4.8 +14.6+ 9.8)/3 + (8.4 +10.7+ 8.1)/3 = 55.6

* normvt_sg:  (25.7+23.0+34.2)/3 + (8.4 +10.7+ 8.1)/3 = 36.7  
* normvt_r2:  (25.7+23.0+34.2)/3 + (8.4 +10.7+ 8.1)/3 = 37.4  
* normvt_sfg: (25.7+23.0+34.2)/3 + (4.8 +14.6+ 9.8)/3 + (8.4 +10.7+ 8.1)/3 = 46.4
* normvt_r2g: (25.7+23.0+34.2)/3 + (8.6+ 11.9+ 8.7)/3 + (8.4 +10.7+ 8.1)/3 = 46.4



replace     normvt_c   = 36.8 if year==2017          //for CDU/CSU
replace 	normvt_cf  = 46.6 if year==2017          //for CDU/CSU-FDP
replace 	normvt_cg  = 45.9 if year==2017          //for CDU/CSU-Green
replace     normvt_cfg = 55.6 if year==2017          //for CDU/CSU-FDP-Green "Jamaika Coalition"

replace     normvt_s   = 27.6 if year==2017          //for SPD
replace     normvt_sg  = 36.7 if year==2017          //for SPD-Green
replace     normvt_r2  = 37.4 if year==2017          //for SPD-Linke
replace     normvt_sfg = 46.4 if year==2017          //for SPD-FDP-Green "Traffic Light Coalition"
replace     normvt_r2g = 46.4 if year==2017          //for SPD-Green-Linke "R2G Coalition"




**********
** Term **
**********


** Depending on the forecasting target we need to change the respective value for term in 2017
** Thus, we create different verions for the term variable

gen term_c = term  //for CDU/CSU-lead government
gen term_s = term  //for SPD-lead government

** Term values for 2017 depending on forcasting target
replace  term_c   = 3 if year==2017          //for CDU/CSU
replace  term_s   = 0 if year==2017          //for SPD




***************************
** Chancellor popularity **
***************************


** Chancellor popularity (similar to 1969 and 2009)

/*
1969: CDU/CSU vote share of Grand Coalition: 0.548 of vote of CDU/CSU & SPD in 1965
Reduces lead in 1969 Chancellor Preference from 65-35 to 58-42
[0,548*30=16]

2009: CDU/CSU vote share of Grand Coalition: 0.507 of vote of CDU/CSU & SPD in 2005
Reduces lead in 2009 Chancellor Preference from 71-29 to 61-39
[0.507*42=21]
*/

*2017: CDU/CSU vote share of Grand Coalition: 41.5/(41.5+25.7)=0.618 of vote of CDU/CSU & SPD in 2013
*Reduces lead in 2017 Chancellor Preference from XX-XX to YY-YY
*[0.618*??=??]

* Adjustment not needed because situation is not comparable to 1969 & 2009! 
* Currently the popularity of Merkel among Union supporters and Schulz among SPD supporters
* resembles more the 2005 situation than the one from the last Grosse Koalition in 2009.
* The numbers for Schulz are decreasing, though. We might reconsider that at a later stage.



* PB Nov II 2016
* "Sollte Martin Schulz gegen Angela Merkel antreten, sprechen sich 47 Prozent für Merkel aus und 39 Prozent für Schulz"
* Thus, 55:45 excluding Dk's

* PB Feb  2017
* "Inzwischen wollen nur noch 38 Prozent Angela Merkel lieber als Kanzlerin, während jetzt 49 Prozent Martin Schulz bevorzugen."

* PB April 2017
* "Bei der Frage, wen man nach der Bundestagswahl lieber als Kanzler oder Kanzlerin hätte, waren 
*  Angela Merkel und Martin Schulz im März gleichauf (Merkel: 44 Prozent; Schulz: 44 Prozent). 
*  Jetzt liegt Merkel mit 48 Prozent vorne, Schulz wünschen sich 40 Prozent als künftigen Kanzler 
*  (Rest zu 100 Prozent hier und im Folgenden jeweils „weiß nicht“). Dabei fällt der Rückhalt für 
*  Merkel in den eigenen Reihen (CDU/CSU-Anhänger: 91 Prozent) etwas höher aus als der für Schulz 
*  bei den SPD-Anhängern (79 Prozent)." 
*  TG: Das entspricht in etwa dem 2005 Werten von Merkel (als Herausforderin) und Schröder (als Kanzler)

* PB Juni 2017
* "Bei der Frage, wen man nach der Bundestagswahl lieber als Kanzler oder Kanzlerin hätte, kann Angela Merkel 
* ihren Vorsprung vor Martin Schulz noch einmal leicht vergrößern. 59 Prozent (Mai: 57 Prozent) wünschen sich 
* weiterhin Angela Merkel, 31 Prozent (Mai: 33 Prozent) möchten Martin Schulz als künftigen Kanzler
* (Rest zu 100 Prozent hier und im Folgenden jeweils „weiß nicht“). Neben den CDU/CSU-Anhängern (95 Prozent) 
* spricht sich auch eine Mehrheit der FDP-Anhänger (82 Prozent) für Merkel aus. Schulz, der in den eigenen 
* Reihen von 73 Prozent unterstützt wird, bevorzugen auch die meisten Linke-Anhänger (55 Prozent). Die Anhänger 
* der Grünen präferieren ebenso etwas häufiger Schulz (44 Prozent; Merkel: 39 Prozent), bei den AfD-Anhängern 
* liegen beide gleichauf (Merkel: 35 Prozent; Schulz: 34 Prozent)."

*  TG: Das entspricht in etwa dem 2005 Werten von Merkel (als Herausforderin) und Schröder (als Kanzler)

***** Popularity Merkel *****
* Include here the values from PB (eventually the mean of the last two PB months)
global merkel1 = 59 /* June 2017 */
global schulz1 = 31 /* June 2017 */

dis( round($merkel1*100/($merkel1+$schulz1),1) ) 
global merkels1 = round($merkel1*100/($merkel1+$schulz1),1)  //DKs are taken out

global merkel2 = 59 /* June 2017 */
global schulz2 = 31 /* June 2017 */

dis( round($merkel2*100/($merkel2+$schulz2),1) ) 
global merkels2 = round($merkel2*100/($merkel2+$schulz2),1)  //DKs are taken out

global merkel = ($merkels1 + $merkels2)/2
dis $merkel

***** Popularity Schulz ****
dis(100-$merkel)
global schulz = 100-$merkel  //DKs are taken out


** Depending on the forecasting target we need to change the respective value for chancellor popularity in 2017
** Thus, we create different verions for the chancellor popularity variable

gen chan2grand_c = chan2grand  //for CDU/CSU-lead government
gen chan2grand_s = chan2grand  //for SPD-lead government

** chancellor popularity values for 2017 depending on forcasting target based on current PB values (merkel1 & schulz1)
replace  chan2grand_c   = $merkel if year==2017          //for CDU/CSU
replace  chan2grand_s   = $schulz if year==2017          //for SPD





************************************
** Get Point Predictions for 2017 **
************************************


*** Run the model and predict CDU/CSU vote share 2017
reg incvt normvt_c term_c chan2grand_c
predict c2017

*** Run the model and predict CDU/CSU-FDP vote share 2017
reg incvt normvt_cf term_c chan2grand_c
predict cf2017


*** Run the model and predict CDU/CSU-Green vote share 2017
reg incvt normvt_cg term_c chan2grand_c
predict cg2017


*** Run the model and predict CDU/CSU-FDP-Green vote share 2017
reg incvt normvt_cfg term_c chan2grand_c
predict cfg2017


*** Run the model and predict SPD vote share 2017
reg incvt normvt_s term_s chan2grand_s
predict s2017


*** Run the model and predict SPD-Green vote share 2017
reg incvt normvt_sg term_s chan2grand_s
predict sg2017

*** Run the model and predict SPD-Linke vote share 2017
reg incvt normvt_r2 term_s chan2grand_s
predict r22017

*** Run the model and predict SPD-FDP-Green vote share 2017
reg incvt normvt_sfg term_s chan2grand_s
predict sfg2017

*** Run the model and predict SPD-Linke-Green vote share 2017
reg incvt normvt_r2g term_s chan2grand_s
predict r2g2017



* Overview over predictions
list year incvt *2017, clean






*******************************************************
** Probability that Forcasting target is above 47.5% **
** (assuming 5% that go to parties not in Bundestag) **
*******************************************************


* generate variable to store forecasting results and confidence intervalls
gen coalition = " "
gen forecast = .
gen lb16 = .
gen lb95 = .
gen ub16 = .
gen ub95 = .




reg incvt normvt chan2grand term

set seed 12345
global nsim = 10000                                         // Define no of simulations
capture drop b*
estsimp regress incvt normvt chan2grand term, sims($nsim)    // Draw 10,000 simulations from Var-Cov Matrix 


********************
*** CDU/CSU alone **
********************

* Define prediction scenario 
setx normvt 36.8 chan2grand $merkel term 3

* QoI: predicted value (on same scale as DV) and save them as new variable
simqi, pv genpv(c17) 
replace coalition = "CDU/CSU" in 1
sum c17
replace forecast = r(mean)
_pctile c17, p(2.5, 8, 92, 97.5)   /* Compute  percentiles and store them in r() */
replace lb16 = r(r2) in 1
replace lb95 = r(r1) in 1
replace ub16 = r(r3) in 1
replace ub95 = r(r4) in 1


* How many simulations are above 47.5% ? 
gen prob_c17 = (c17>47.5)                                     
tab prob_c17



****************************
*** CDU/CSU-FDP Coalition **
****************************

* Define prediction scenario 
setx normvt 46.6 chan2grand $merkel term 3

* QoI: predicted value (on same scale as DV) and save them as new variable
simqi, pv genpv(cf17) 
replace coalition = "CDU/CSU-FDP" in 2
sum cf17
replace forecast = r(mean) in 2
_pctile cf17, p(2.5, 8, 92, 97.5)   /* Compute  percentiles and store them in r() */
replace lb16 = r(r2) in 2
replace lb95 = r(r1) in 2
replace ub16 = r(r3) in 2
replace ub95 = r(r4) in 2

* How many simulations are above 47.5% ? 
gen prob_cf17 = (cf17>47.5)                                     
tab prob_cf17



******************************
*** CDU/CSU-Green Coalition **
******************************

* Define prediction scenario 
setx normvt 45.9 chan2grand $merkel term 3

* QoI: predicted value (on same scale as DV) and save them as new variable
simqi, pv genpv(cg17) 
replace coalition = "CDU/CSU-Grüne" in 3
sum cg17
replace forecast = r(mean) in 3
_pctile cg17, p(2.5, 8, 92, 97.5)    /* Compute  percentiles and store them in r() */
replace lb16 = r(r2) in 3
replace lb95 = r(r1) in 3
replace ub16 = r(r3) in 3
replace ub95 = r(r4) in 3

* How many simulations are above 47.5% ? 
gen prob_cg17 = (cg17>47.5)                                     
tab prob_cg17



**********************************
*** CDU/CSU-FDP-Green Coalition **
**********************************

* Define prediction scenario 
setx normvt 55.6 chan2grand $merkel term 3

* QoI: predicted value (on same scale as DV) and save them as new variable
simqi, pv genpv(cfg17) 
replace coalition = "CDU/CSU-FDP-Grüne" in 4
sum cfg17
replace forecast = r(mean) in 4
_pctile cfg17, p(2.5, 8, 92, 97.5)   /* Compute  percentiles and store them in r() */
replace lb16 = r(r2) in 4
replace lb95 = r(r1) in 4
replace ub16 = r(r3) in 4
replace ub95 = r(r4) in 4

* How many simulations are above 47.5% ? 
gen prob_cfg17 = (cfg17>47.5)                                     
tab prob_cfg17



****************
*** SPD alone **
****************

* Define prediction scenario 
setx normvt 27.6 chan2grand $schulz term 0

* QoI: predicted value (on same scale as DV) and save them as new variable
simqi, pv genpv(s17) 
replace coalition = "SPD" in 5
sum s17
replace forecast = r(mean) in 5
_pctile s17, p(2.5, 8, 92, 97.5)    /* Compute  percentiles and store them in r() */
replace lb16 = r(r2) in 5
replace lb95 = r(r1) in 5
replace ub16 = r(r3) in 5
replace ub95 = r(r4) in 5

* How many simulations are above 47.5% ? 
gen prob_s17 = (s17>47.5)                                     
tab prob_s17



* What is the probability that SPD is larger than CDU/CSU?
* calculate difference between SPD and CDU/CSU prediction 
* and check how many simulations are >0

gen diff_sc = s17-c17
gen prob_sc17 = (diff_sc>0) 
tab prob_sc17



set more off                                      /* let output scroll    */

* create variables that should get plotted 
* missing values get subsequently replaced by simulation result for a given scenario

generate plos = .                                /* lower bound for SPD prediction */
generate pups = .                                /* upper bound for SPD prediction */
generate ploc = .                                /* lower bound for CDU prediction */
generate pupc = .                                /* upper bound for CDU prediction */
generate plosc = .                                /* lower bound for SPD-CDU prediction */
generate pupsc = .                                /* upper bound for SPD-CDU prediction */
generate sc17 = . 
generate probsc = . 

* generate x-axis of plot
generate ageaxis = 30 + (_n-1)/10 in 1/401                  /* contains 30,31,..,70 */

* Let Merkel's Popularity vary from 30-70

local a = 30                                      /* begin with 30 */
while `a' <= 70 {                                 /* until 70.  */
   display "Simulating for $merkel = `a'"             /* monitor our progress */
   
   setx normvt 27.6 chan2grand (100-`a') term 0
   simqi, pv genpv(s17s)
   _pctile s17s, p(2.5,97.5)			            /* fetch percentiles for  CI */
   replace plos = r(r1) if ageaxis==float(`a')	        /* save lower bound of ci  */
   replace pups = r(r2) if ageaxis==float(`a')            /* save upper bound of ci  */
   
   setx normvt 36.8 chan2grand `a' term 3
   simqi, pv genpv(c17s)                   
   _pctile c17s, p(2.5,97.5)			            /* fetch percentiles for 95% CI */
   replace ploc = r(r1) if ageaxis==float(`a')            /* save lower bound of ci  */     
   replace pupc = r(r2) if ageaxis==float(`a')	           /* save upper bound of ci  */
   
    gen diff = s17s-c17s                       /* 10000 different values for the differences */
    egen  diff17 = mean(diff)
	scalar diff_hat = diff17 
	replace sc17 = diff_hat if ageaxis==float(`a')
	
	_pctile diff, p(2.5,97.5)			            /* fetch percentiles for 95% CI */
   replace plosc = r(r1) if ageaxis==float(`a')            /* save lower bound of ci  */     
   replace pupsc = r(r2) if ageaxis==float(`a')	           /* save upper bound of ci  */
   
   gen prob_diff = (diff>0) 
   sum prob_diff
   replace probsc = r(mean)*100 if ageaxis==float(`a') 
   
   drop s17s c17s diff diff17 prob_diff                   /* clean-up our mess    */
   local a = `a' + .1				                /* advance Merkel popularity by .1  */
}
sort ageaxis

gen spdhat = (pups -plos )/2 + plos  
gen cduhat = (pupc -ploc )/2 + ploc 

sum ageaxis if probsc>=50


*****************
** Abbildung 3 **
*****************

#delimit ;
graph twoway  rarea plos  pups ageaxis , color(gs10)
|| rarea ploc  pupc ageaxis , color(gs3)
|| line probsc ageaxis if ageaxis<= 45.1 , sort lpattern(dash) lcolor(gs10)
|| line probsc ageaxis if ageaxis > 45.1 , sort lcolor(black)
|| line spdhat ageaxis  , sort lcolor(black)
|| line cduhat ageaxis  , sort lcolor(black)
|| pcarrowi 50 45.1 50 70 , lcolor(black)
|| pcarrowi 50 45.1 50 30 , lcolor(black)
    xline(45.1, lcolor(gs10))
    xlabel(30(10)70 45.1, nogrid  angle(horizontal))
    xscale(titlegap(10) nofextend)
    yscale(nofextend  titlegap(3))
    ylabel(0(20)100 50, nogrid angle(horizontal))
	legend(off)   
    scheme(s1mono)
    text(54 46 "CDU/CSU > SPD", place(r) )  
	text(54 44 "SPD > CDU/CSU", place(l) ) 
	xtitle("Kanzlerunterstützung Merkel [in %]", color(black) alignment(bottom) j(left) )    
	ytitle("Vorhergesagter Zweitstimmenanteil" "bzw. Wahrscheinlichkeit SPD > CDU/CSU")            
    graphregion(color(white)) plotregion( color(white)) bgcolor(white)
saving(spd_cdu, replace);
#delimit cr
graph export Abbildung3.pdf, replace
graph export Abbildung3.tif, replace
graph export Abbildung3.png, replace
graph export Abbildung3.eps, replace preview(on)


* || pcarrowi 50 45.1 0 45.1 , lpattern(grid)
* || function y=50   , range(30 70) lcolor(gs10) lpattern(dash)
* yline(50, lcolor(black) lpattern(dash))


* Merkel needs a popularity rating of 46 in order for the CDU/CSU to become the strongest party




  	

**************************
*** SPD-Green Coalition **
**************************

* Define prediction scenario 
setx normvt 36.7 chan2grand $schulz term 0

* QoI: predicted value (on same scale as DV) and save them as new variable
simqi, pv genpv(sg17) 
replace coalition = "SPD-Grüne" in 6
sum sg17
replace forecast = r(mean) in 6
_pctile sg17, p(2.5, 8, 92, 97.5)    /* Compute  percentiles and store them in r() */
replace lb16 = r(r2) in 6
replace lb95 = r(r1) in 6
replace ub16 = r(r3) in 6
replace ub95 = r(r4) in 6

* How many simulations are above 47.5% ? 
gen prob_sg17 = (sg17>47.5)                                     
tab prob_sg17


**************************
*** SPD-Linke Coalition **
**************************

* Define prediction scenario 
setx normvt 37.4 chan2grand $schulz term 0

* QoI: predicted value (on same scale as DV) and save them as new variable
simqi, pv genpv(r217) 
replace coalition = "SPD-Linke" in 7
sum r217
replace forecast = r(mean) in 7
_pctile r217, p(2.5, 8, 92, 97.5)    /* Compute  percentiles and store them in r() */
replace lb16 = r(r2) in 7
replace lb95 = r(r1) in 7
replace ub16 = r(r3) in 7
replace ub95 = r(r4) in 7

* How many simulations are above 47.5% ? 
gen prob_r217 = (r217>47.5)                                     
tab prob_r217




******************************
*** SPD-FDP-Green Coalition **
******************************

* Define prediction scenario 
setx normvt 46.4 chan2grand $schulz term 0

* QoI: predicted value (on same scale as DV) and save them as new variable
simqi, pv genpv(sfg17) 
replace coalition = "SPD-FDP-Grüne" in 8
replace coalition = "SPD-Grüne-Linke" in 9
sum sfg17
replace forecast = r(mean) in 8
replace forecast = r(mean) in 9
_pctile sfg17, p(2.5, 8, 92, 97.5)    /* Compute  percentiles and store them in r() */
replace lb16 = r(r2) in 8
replace lb95 = r(r1) in 8
replace ub16 = r(r3) in 8
replace ub95 = r(r4) in 8

replace lb16 = r(r2) in 9
replace lb95 = r(r1) in 9
replace ub16 = r(r3) in 9
replace ub95 = r(r4) in 9

* How many simulations are above 47.5% ? 
gen prob_sfg17 = (sfg17>47.5)                                     
tab prob_sfg17


********************************
*** SPD-Linke-Green Coalition **
********************************

* Same value as above because value for nomal vote in 2017 is the same for both coalitons.

list coalition forecast lb* ub* in 1/9


* Overview over prob. to be greater than 47.5% (= no of 1#s)
tab prob_c17
tab prob_cf17 
tab prob_cg17 
tab prob_cfg17 
tab prob_s17 
tab prob_sg17 
tab prob_r217
tab prob_sfg17 // same as R2G-coalition
*tab prob_r2g17
tab prob_sc17

gen prob = .

sum prob_c17
replace prob = r(mean)*100 in 1
sum prob_cf17 
replace prob = r(mean)*100 in 2
sum prob_cg17 
replace prob = r(mean)*100 in 3
sum prob_cfg17 
replace prob = r(mean)*100 in 4
sum prob_s17 
replace prob = r(mean)*100 in 5
sum prob_sg17 
replace prob = r(mean)*100 in 6
sum prob_r217
replace prob = r(mean)*100 in 7
sum prob_sfg17 
replace prob = r(mean)*100 in 8
sum prob_sfg17
replace prob = r(mean)*100 in 9
sum prob_sc17
replace prob = r(mean)*100 in 10

format forecast %9.1f
ren coalition Koalition
replace Koalition = "SPD>CDU/CSU" in 10
list Koalition forecast lb* ub* prob in 1/10, clean




*****************
** Abbildung 2 **
*****************




capture drop xaxis
gen xaxis = _n in 1/9
#delimit ;
twoway (scatter xaxis forecast,  mlwidth(vthin) mfcolor(gs6)  lcolor(black) mlabel(forecast) mlabcolor(black) mlabposition(1) mlabgap(*3) mlabsize(vsmall) ) 
( rspike lb95 ub95 xaxis,  lwidth(vthin) lcolor(black) horizontal),
legend(off) ytitle(" ") 
xline(47.5)
ylabel(  1 "CDU/CSU" 
  2 "CDU/CSU-FDP" 
  3 "CDU/CSU-Grüne"  
  4 "CDU/CSU-FDP-Grüne"  
  5 "SPD"  
  6 "SPD-Grüne"  
  7 "SPD-Linke " 
  8 "SPD-FDP-Grüne" 
  9 "SPD-Grüne-Linke"
, labsize(small) angle(horizontal) noticks grid)
yscale(noline) xscale( nofextend) 
scheme(s1mono)
xtitle("Vorhergesagter Zweitstimmenanteil", color(black) alignment(bottom )) xscale(titlegap(3) )
xlabel(25 "25" 30 "30" 35 "35" 40 "40" 45 "45" 47.5 "47,5" 50 "50" 55 "55",  labsize(small) labels tick)
graphregion(color(white)) plotregion( color(white) ) bgcolor(white)
saving(zweitstimmen, replace)
;
#delimit cr
drop xaxis


/* without 47.5 refence line
capture drop xaxis
gen xaxis = _n in 1/9
#delimit ;
twoway (scatter xaxis forecast,  mlwidth(vthin) mfcolor(gs6)  lcolor(black) mlabel(forecast) mlabcolor(black) mlabposition(1) mlabgap(*3) mlabsize(vsmall) ) 
( rspike lb95 ub95 xaxis,  lwidth(vthin) lcolor(black) horizontal),
legend(off) ytitle(" ") 
ylabel(  1 "CDU/CSU" 
  2 "CDU/CSU-FDP" 
  3 "CDU/CSU-Grüne"  
  4 "CDU/CSU-FDP-Grüne"  
  5 "SPD"  
  6 "SPD-Grüne"  
  7 "SPD-Linke " 
  8 "SPD-FDP-Grüne" 
  9 "SPD-Grüne-Linke"
, labsize(small) angle(horizontal) noticks grid)
yscale(noline) xscale( nofextend) 
scheme(s1mono)
xtitle("Vorhergesagter Zweitstimmenanteil", color(black) alignment(bottom )) xscale(titlegap(3) )
xlabel(25(5)55,  labsize(small) labels tick)
graphregion(color(white)) plotregion( color(white) ) bgcolor(white)
saving(zweitstimmen, replace)
;
#delimit cr
drop xaxis
*/

graph export zweitstimmen.pdf, replace
graph export zweitstimmen.tif, replace
graph export zweitstimmen.png, replace
graph export zweitstimmen.eps, replace preview(on)




* Graph with different CI

capture drop xaxis
gen xaxis = _n in 1/9
#delimit ;
twoway (scatter xaxis forecast,  mlwidth(vthin) mfcolor(gs6)  lcolor(black) mlabel(forecast) mlabcolor(black) mlabposition(1) mlabgap(*3) mlabsize(vsmall) ) 
( rspike lb95 ub95 xaxis,  lwidth(vthin) lcolor(black) horizontal)
( rspike lb16 ub16 xaxis,   lcolor(black) horizontal),
legend(off) ytitle(" ") 
xline(47.5)
ylabel(  1 "CDU/CSU" 
  2 "CDU/CSU-FDP" 
  3 "CDU/CSU-Grüne"  
  4 "CDU/CSU-FDP-Grüne"  
  5 "SPD"  
  6 "SPD-Grüne"  
  7 "SPD-Linke " 
  8 "SPD-FDP-Grüne" 
  9 "SPD-Grüne-Linke"
, labsize(small) angle(horizontal) noticks grid)
yscale(noline) xscale( nofextend) 
scheme(s1mono)
xtitle("Vorhergesagter Zweitstimmenanteil", color(black) alignment(bottom )) xscale(titlegap(3) )
xlabel(20 "20" 25 "25" 30 "30" 35 "35" 40 "40" 45 "45" 47.5 "47,5" 50 "50" 55 "55",  labsize(small) labels tick)
graphregion(color(white)) plotregion( color(white) ) bgcolor(white)
saving(zweitstimmen, replace)
;
#delimit cr
drop xaxis



graph export Abbildung2.pdf, replace
graph export Abbildung2.tif, replace
graph export Abbildung2.png, replace
graph export Abbildung2.eps, replace preview(on)






drop b* 

******************************************
** Generate graph of Chances of Winning **
******************************************


* genvariable to hold coalition names and relative freq of success (>47.5%)
gen coalition = _n in 1/9
gen chance1 = .

* grab relative freq of success and save it to variable
tab prob_cf17, matcell(xcf17)
replace chance1 = xcf17[2,1] in 4

tab prob_cg17, matcell(xcg17)
replace chance1 = xcg17[2,1] in 3

tab prob_cfg17, matcell(xcfg17) 
replace chance1 = xcfg17[1,1] in 7   /* [1,1] because we get 100% */
 
tab prob_sg17, matcell(xsg17) 
replace chance1 = xsg17[2,1] in 6

tab prob_r217, matcell(xr217) 
replace chance1 = xr217[2,1] in 5

tab prob_sfg17, matcell(xsfg17)
replace chance1 = xsfg17[2,1] in 8/9

tab prob_sc17, matcell(xsc17)
replace chance1 = xsc17[2,1] in 1




* for graph below
recode chance1 .=0    in 1/9
replace coalition = . in 2
replace chance1= . in 2
tab chance1


* gen variable to hold predicted probabilities of each scenario
gen chance = (chance1/$nsim)*100
tab chance

lab var chance "Chance of Winning [in Percent]"
lab var coalition "Forecasting target"

label define coalition 9 "SPD-Greens-Linke" 8 "SPD-Greens-FDP" 7 "CDU/CSU-FDP-Greens" 6 "SPD-Greens" 
label define coalition 5 "SPD-Linke" 4 "CDU/CSU-FDP" 3 "CDU/CSU-Greens" 2 " " 1 "SPD > CDU/CSU", add

label values coalition coalition


/*
replace coalition = "SPD-Greens-Linke" in 9
replace coalition = "SPD-Greens-FDP" in 8
replace coalition = "CDU/CSU-FDP-Greens" in 7
replace coalition = "SPD-Greens" in 6
replace coalition = "SPD-Linke" in 5
replace coalition = "CDU/CSU-FDP" in 4
replace coalition = "CDU/CSU-Greens" in 3
replace coalition = "SPD > CDU/CSU" in 1
*/

 

format chance %9.0f
gen chance_1 = chance
format chance_1 %9.1f


#delimit ;
twoway  dropline chance coalition if chance>2, horizontal lcolor(black) mlabel(chance) mlabcolor(black) mcolor(black) mlabgap(*3) mlabsize(*1) ||
dropline chance coalition if chance<2, horizontal  mlabel(chance_1) mlabcolor(black)  lcolor(white) mcolor(black) mlabgap(*3)
legend(off) ytitle(" ") 
ylabel( 9 "SPD-Greens-Linke" 8 "SPD-Greens-FDP" 7 "CDU/CSU-FDP-Greens" 6 "SPD-Greens" 
        5 "SPD-Linke" 4 "CDU/CSU-FDP" 3 "CDU/CSU-Greens" 1 "SPD > CDU/CSU", 
		labsize(medsmall) angle(horizontal) noticks nogrid) 
yscale(noline) xscale( nofextend) 
xtitle("Chances of Each Coalition Winning a Majority of Seats,"
"and Chances of SPD Beating CDU/CSU", color(black) alignment(bottom )) xscale(titlegap(3) )
xlabel(0(20)100 ,  labsize(small) labels tick)
graphregion(color(white)) plotregion( color(white) ) bgcolor(white)
saving(chance, replace)
;
#delimit cr


graph export chance.pdf, replace
graph export chance.tif, replace
graph export chance.png, replace
graph export chance.eps, replace preview(on)



*****************
** Abbildung 1 **
*****************



********* graph in German
#delimit ;
twoway  dropline chance coalition if chance>2, horizontal lcolor(black) mlabel(chance) mlabcolor(black) mcolor(black) mlabgap(*.6) mlabsize(*1) ||
dropline chance coalition if chance<2, horizontal  mlabel(chance_1) mlabcolor(black)  lcolor(white) mcolor(black) mlabgap(*3)
legend(off) ytitle(" ") 
ylabel( 9 "SPD-Grüne-Linke (R2G)" 8 "SPD-FDP-Grüne (Ampel)" 7 "CDU/CSU-FDP-Grüne (Jamaika)" 6 "SPD-Grüne" 
        5 "SPD-Linke" 4 "CDU/CSU-FDP" 3 "CDU/CSU-Grüne" 1 "SPD > CDU/CSU", 
		labsize(medsmall) angle(horizontal) noticks nogrid) 
yscale(noline) xscale( nofextend) 
xtitle("Wahrscheinlichkeit für absolute Mehrheit der Sitze" 
"bzw.  SPD stärker als CDU/CSU", j(left) size(small) color(black) alignment(bottom )) xscale(titlegap(3) )
xlabel(0(20)100 ,  labsize(small) labels tick)
graphregion(color(white)) plotregion( color(white) ) bgcolor(white)
saving(chanceg, replace)
;
#delimit cr



graph export Abbildung1.pdf, replace
graph export Abbildung1.tif, replace
graph export Abbildung1.png, replace
graph export Abbildung1.eps, replace preview(on)


exit







